# LSB Test Execution Framework
# Vsw4 test module
#
# Copyright (C) 2007 The Linux Foundation. All rights reserved.
#
# This program has been developed by ISP RAS for LF with some parts
# derived from lsb-autotest written by Jiri Dluhos <jdluhos@suse.cz>
# Copyright (C) 2005-2007 SuSE Linux Products GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

package Vsw4_test;
use strict;

use Common;
use Packages;

use Tests::X11::X11_common;
@Vsw4_test::ISA = qw(X11_common);

=head ##
Class Vsw4_test Inherits X11_common;
=cut ##

sub new {
    my $self  = X11_common->new();
    $self->{NAME} = "vsw4";
    $self->{DISPLAYNAME} = "X11 Tests (Vsw4)";
    $self->{DESCRIPTION} = "LSB X Window System test suite."
        ." These tests are derived from the VSW4 XTest test suites.";
    $self->{PACKAGES} .= " lsb-tet3 lsb-xvfb lsb-test-vsw4";
    $self->{SOURCES} .= " runtime";
    $self->{BETA_SOURCES} .= " runtime";
    $self->{SNAPSHOT_SOURCES} .= " /snapshots/tet-harness /snapshots/vsw4-test";

    bless($self);
    return $self;
}

sub check {
    my $self = shift;
    my $failed = 0;
    
    # Vsw4 depends on the xlsfonts command
    unless (does_shell_know ("xlsfonts")) {
        complain ("The ".$self->name." test can't be run."
            ." Can't find the 'xlsfonts' command."
        );
        $failed = 1;
    }
    
    return 0 if $failed;
    
    return X11_common::check($self);
}

sub packages {
    my $self = shift;
    my $lsb_ver = shift;

    if ( !defined($lsb_ver) ) { return $self->{PACKAGES}; }

    if ( $lsb_ver eq "3.0" || $lsb_ver eq "3.1" ) {
        my $packages = $self->{PACKAGES};
        $packages =~ s/ lsb-xvfb / /g;
        return $packages;
    }
    return $self->{PACKAGES};    
}

sub run {
    my $self = shift;
    
    # Short scenario:
    if ( $short_scenarios ) {
        inform("Use short scenario");
        my $result = backup_and_replace( "/opt/lsb/test/vsw4/xtest/link_scen",
            "$script_directory/Tests/X11/vsw4_short_scen" );
		#if ( $result != 0 ) { inform ("Test will be skipped"); return 1; }
    }
    
    return X11_common::run($self);
}

sub journal {
    my $self = shift;
    
    if ( $lsb_version eq '3.0' || $lsb_version eq '3.1' ) {
        store_journal_info(
            "Certification Tests/Runtime Interface Tests/".$self->{DISPLAYNAME}
            , "x11_test", "$results_dir/test_journals/x11_test.journal", $self);
    } else {
        # Was pushed out since LSB 3.2
        store_journal_info(
            "Unofficial Tests/Runtime Interface Tests/".$self->{DISPLAYNAME}
            , "x11_test", "$results_dir/test_journals/x11_test.journal", $self);
    }
}

sub cleanup {
    my $self = shift;
    
    X11_common::cleanup($self);
    
    if ( $short_scenarios ) {
        my $scen_file = "/opt/lsb/test/vsw4/xtest/link_scen";
        if (-f "$scen_file.orig" ) {
            cmd ("cp -f $scen_file.orig $scen_file"); 
        }
    }
}
1; # return value
